==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fGoto.h <==
// class soot.coffi.Instruction_Goto

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class e83ce1cad21899dd soot_coffi_Instruction__5fGoto
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fGoto_H_
#define _JC_soot_coffi_Instruction__5fGoto_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fGoto$sub_refs	_jc_soot_coffi_Instruction__5fGoto$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$sub_nonrefs	_jc_soot_coffi_Instruction__5fGoto$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$refs	_jc_soot_coffi_Instruction__5fGoto$refs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$nonrefs	_jc_soot_coffi_Instruction__5fGoto$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$object	_jc_soot_coffi_Instruction__5fGoto$object;

typedef const struct _jc_soot_coffi_Instruction__5fGoto$vmethods	_jc_soot_coffi_Instruction__5fGoto$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fGoto$vtable	_jc_soot_coffi_Instruction__5fGoto$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fGoto$vtype	_jc_soot_coffi_Instruction__5fGoto$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fGoto$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fGoto$object *);

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fGoto$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fGoto$object *, struct _jc_soot_coffi_Instruction$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fGoto$method_info$branchpoints$0387b0529fae51a0;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fGoto$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fGoto$object *, struct _jc_soot_coffi_Instruction$object *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fGoto$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fGoto$vmethods	soot_coffi_Instruction__5fGoto;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fGoto$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fGoto$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGoto$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGoto$refs {
    _jc_soot_coffi_Instruction__5fGoto$sub_refs	soot_coffi_Instruction__5fGoto;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGoto$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGoto$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fGoto$sub_nonrefs	soot_coffi_Instruction__5fGoto;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fGoto$object {
	_jc_soot_coffi_Instruction__5fGoto$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fGoto$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fGoto$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fGoto$vtype _jc_soot_coffi_Instruction__5fGoto$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fGoto, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fGoto$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fGoto_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fGoto.h <==
// class soot.coffi.Instruction_Goto

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class e83ce1cad21899dd soot_coffi_Instruction__5fGoto
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fGoto_H_
#define _JC_soot_coffi_Instruction__5fGoto_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fGoto$sub_refs	_jc_soot_coffi_Instruction__5fGoto$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$sub_nonrefs	_jc_soot_coffi_Instruction__5fGoto$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$refs	_jc_soot_coffi_Instruction__5fGoto$refs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$nonrefs	_jc_soot_coffi_Instruction__5fGoto$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGoto$object	_jc_soot_coffi_Instruction__5fGoto$object;

typedef const struct _jc_soot_coffi_Instruction__5fGoto$vmethods	_jc_soot_coffi_Instruction__5fGoto$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fGoto$vtable	_jc_soot_coffi_Instruction__5fGoto$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fGoto$vtype	_jc_soot_coffi_Instruction__5fGoto$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fGoto$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fGoto$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fGoto$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fGoto$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fGoto$method_info$branchpoints$0387b0529fae51a0;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fGoto$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fGoto$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fGoto$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fGoto$vmethods	soot_coffi_Instruction__5fGoto;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fGoto$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fGoto$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGoto$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGoto$refs {
    _jc_soot_coffi_Instruction__5fGoto$sub_refs	soot_coffi_Instruction__5fGoto;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGoto$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGoto$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fGoto$sub_nonrefs	soot_coffi_Instruction__5fGoto;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fGoto$object {
	_jc_soot_coffi_Instruction__5fGoto$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fGoto$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fGoto$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fGoto$vtype _jc_soot_coffi_Instruction__5fGoto$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fGoto, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fGoto$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fGoto_H_ */
